removeLast method
Removes the last object from this list.
This method reduces the length of this by one.
The list must not be empty.
If you want to recover the removed item, you can pass a mutable removedItem.
Implementation
@useResult
IList<T> removeLast([Output<T>? removedItem]) => removeAt(length - 1, removedItem);